@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.5
+#!/usr/local/bin/python2.7
 # -*- coding: UTF-8 -*-
 
 # Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
@@ -72,8 +72,8 @@ class main_window:
 		columnchapters = gtk.TreeViewColumn("Title", rendererchapters, text=1)
 		lchapters.append_column(columnchapters)
 		
-		ltitles.connect("button_release_event",self.on_titleclick)
-		lchapters.connect("button_release_event",self.on_chapterclick)
+		#ltitles.connect("button_release_event",self.on_titleclick)
+		#lchapters.connect("button_release_event",self.on_chapterclick)
 		
 		self.set_default_global()
 		
@@ -321,7 +321,7 @@ class main_window:
 			elif (line[:9]=="cpu cores"):
 				cpu_cores=self.get_number(line)
 
-		if(ncores==0.0):
+		if(ncores<=1.0):
 			return 1
 		else:
 			return int(ncores)
@@ -470,7 +470,7 @@ class main_window:
 		print "PAL: "+str(self.global_vars["PAL"])
 	
 	
-	def on_chapterclick(self,widget,event):
+	def on_chapterclick(self,widget,event,step=None):
 	
 		""" Callback for click event in the chapter list. It
 		sets the buttons and film info """
@@ -539,7 +539,7 @@ class main_window:
 	# titles-related callbacks
 	
 	
-	def on_titleclick(self,widget,event):
+	def on_titleclick(self,widget,event,step=None):
 	
 		""" Callback for click event in the title list. It refreshes the chapters
 		and sets the buttons and film info """
