@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 # -*- coding: UTF-8 -*-
 
 # Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
@@ -223,15 +223,17 @@ class check_utf(devede_executor.executor):
 		while True:
 			value=self.read_full16(file, format_b)
 			if value==True:
+				print "True"
 				return True
 			if value==False:
+				print "False"
 				return False
 			# value can be an integer too, that's why I put both IFs
 
 	
 	def convert_to_UTF8(self,infile_n,outfile_n,origin_format):
 		
-		command_line='iconv -f '+str(origin_format)+' -t UTF8 "'+str(infile_n)+'" -o "'+str(outfile_n)+'"'
+		command_line='iconv -f '+str(origin_format)+' -t UTF-8 "'+str(infile_n)+'" > "'+str(outfile_n)+'"'
 		return self.launch_shell(command_line).wait()
 	
 	
